diff src/getchar.c @ 3448:c1a6e1745cb5 v7.3.489

updated for version 7.3.489 Problem: CTRL-] in Insert mode does not expand abbreviation when used in a mapping. (Yichao Zhou) Solution: Special case using CTRL-]. (Christian Brabandt)
author Bram Moolenaar <bram@vim.org>
date Thu, 05 Apr 2012 16:07:06 +0200
parents a27fac494e70
children f52d2ea0f81c
line wrap: on
line diff
--- a/src/getchar.c
+++ b/src/getchar.c
@@ -4352,8 +4352,9 @@ check_abbr(c, ptr, col, mincol)
 
     if (typebuf.tb_no_abbr_cnt)	/* abbrev. are not recursive */
 	return FALSE;
-    if ((KeyNoremap & (RM_NONE|RM_SCRIPT)) != 0)
-	/* no remapping implies no abbreviation */
+
+    /* no remapping implies no abbreviation, except for CTRL-] */
+    if ((KeyNoremap & (RM_NONE|RM_SCRIPT)) != 0 && c != Ctrl_RSB)
 	return FALSE;
 
     /*